NCCHRead

Trait NCCHRead 

pub trait NCCHRead {
    // Required method
    fn read_ncch(
        &mut self,
        partition: NCCHPartitionEntry,
    ) -> Result<Option<NCCH>, Error>;
}

Required Methods

fn read_ncch( &mut self, partition: NCCHPartitionEntry, ) -> Result<Option<NCCH>, Error>

Parses the 3DS ROM metadata from the object provided, returning a Header object with the header metadata.

Errors

Returns Error::Parse if the header cannot be found or if a field in the header contains an unexpected value. Returns Error::Io if an IO error took place while reading from the file.

Implementors

Source

impl<T: Read + Seek> NCCHRead for T